wrap the datapasta around itself
tortellini(col_struct, defn_width = 80, indent_context = 0, add_comma = TRUE)input structure - a split apart column definition
total number of characters in a line (includes column name and indent on line 1)
the level of indent in spaces in the current editor pane
add one final comma to the end of the wrapped column def? Useful when pasting together columns.
w wrapped string