Guesses the separator based on a simple heuristic over the first 10 or less rows: The separator chosen is the one that leads to the most columns, whilst parsing the same number of columns for each line (var=0). The guessing algorithm ignores blank lines - which are lines that contain only the separator. Options are in `c(",","\t","\|",";")`
guess_sep(char_vec)a table from the clipboard in character vector form.
the separator selected to parse char_vec as a table